.. moduleauthor:: Paul Ross <apaulross@gmail.com>
.. sectionauthor:: Paul Ross <apaulross@gmail.com>

.. Description of TotalDepth command line tools

######################
Command Line Tools
######################

TotalDepth provides a number of tools run from the command line that can analyse and visualise petrophysical data.
All the command line tools start with ``td``.

.. toctree::
    :maxdepth: 2
   
    TD_cmd_line_tools
    LIS_cmd_line_tools
    RP66V1_cmd_line_tools
